@@ -539,7 +539,6 @@ static void set_sockaddr(struct SockAddr *sa,struct CharAddr *ca,int port) {
 static int parse_port(char *port,struct Allowed *into) {
     into->port = 0;
     if ( port ) {
-	*(port++) = 0;
 	int p;
 	if ( sscanf( port, "%d", &p ) != 1 || p < 1 || p > 65535 ) {
 	    // Bad port number
@@ -554,7 +553,6 @@ static int parse_port(char *port,struct Allowed *into) {
 // Capture an optional bits sub phrase [/<bits>], zeroing the "/"
 static int parse_bits(char *bits,int max,struct Allowed *into) {
     if ( bits ) {
-	*(bits++) = 0;
 	int b;
 	if ( sscanf( bits, "%d", &b ) != 1 || b < 0 || b > max ) {
 	    return 1;
@@ -602,8 +600,9 @@ static int parse_allowed(char *arg,struct Allowed *into) {
 	    for ( ; *p && !strchr( ":/=", *p); p++ ) ;
 	}
     }
+    VERBOSE3OUT( "after ip: %s\n", p );
     e = *p;
-    *p = 0;
+    *(p++) = 0;
     struct addrinfo *result;
     struct addrinfo hints = { 0 };
     hints.ai_family = family;
@@ -621,6 +620,7 @@ static int parse_allowed(char *arg,struct Allowed *into) {
     }
     into->bits = ( family == AF_INET )? 32 : 128;
     if ( e == '/' ) {
+	VERBOSE3OUT( "bits: %s\n", p );
 	if ( parse_bits( p, into->bits, into ) ) {
 	    fprintf( stderr, "bad bits\n" );
 	    return 1; // Failure
@@ -632,22 +632,23 @@ static int parse_allowed(char *arg,struct Allowed *into) {
 		return 1;
 	    }
 	}
-	p++;
+	for ( ; *p && !strchr( ":=", *p ); p++ ) ;
 	e = *p;
+	*(p++) = 0;
     }
     into->addr.width = ( family == AF_INET )? 4 : 16;
     if ( e == ':' ) {
+	VERBOSE3OUT( "port: %s\n", p );
 	if ( parse_port( p, into ) ) {
 	    fprintf( stderr, "bad port\n" );
 	    return 1;
 	}
 	p = strchr( p+1, '=' );
 	e = *p;
+	*(p++) = 0;
     }
     if ( e == '=' ) {
-	*(p++) = 0;
-	into->psk.keyfile = malloc( strlen( p ) );
-	strcpy( into->psk.keyfile, p );
+	into->psk.keyfile = p; // points into buffer
     }
     return 0;
 }
@@ -1250,7 +1251,9 @@ static void route_packet(PacketItem *pi) {
     //ssize_t len = pi->len;
     struct Interface *x = input_check( pi );
     if ( x == 0 ) {
-	VERBOSE2OUT( "not a nice packet\n" );
+	if ( pi->len > 0 ) {
+	    VERBOSE2OUT( "not a nice packet %ld\n", pi->len );
+	}
 	return; // not a nice packet
     }
     if ( ( *pi->buffer & 1 ) == 0 ) {
